@@ -24,7 +24,6 @@
 
 defined('MOODLE_INTERNAL') || die();
 
-$plugin->version   = 2014111000;        // The current plugin version (Date: YYYYMMDDXX)
-$plugin->requires  = 2014110400;        // Requires this Moodle version
+$plugin->version   = 2021051700;        // The current plugin version (Date: YYYYMMDDXX).
+$plugin->requires  = 2021051100;        // Requires this Moodle version.
 $plugin->component = 'enrol_category';  // Full name of the plugin (used for diagnostics)
-$plugin->cron      = 60;
