@@ -17,13 +17,10 @@
  * Autocomplete wrapper for select2 library.
  *
  * @module     core/form-autocomplete
- * @class      autocomplete
- * @package    core
  * @copyright  2015 Damyon Wiese <damyon@moodle.com>
  * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
  * @since      3.0
  */
-/* globals require: false */
 define(
     ['jquery', 'core/log', 'core/str', 'core/templates', 'core/notification', 'core/loadingicon', 'core/aria'],
 function($, log, str, templates, notification, LoadingIcon, Aria) {
@@ -188,6 +185,7 @@ function($, log, str, templates, notification, LoadingIcon, Aria) {
      *
      * @param   {Object} state
      * @param   {Array} items
+     * @returns {Boolean}
      */
     var hasItemListChanged = function(state, items) {
         if (state.items.length !== items.length) {
@@ -1034,7 +1032,7 @@ function($, log, str, templates, notification, LoadingIcon, Aria) {
             return pendingPromise;
     };
 
-    return /** @alias module:core/form-autocomplete */ {
+    return {
         // Public variables and functions.
         /**
          * Turn a boring select box into an auto-complete beast.
